import { world, system, EquipmentSlot } from "@minecraft/server";

// Função para recuperar a quantidade máxima de vidas do jogador
const getMaxLives = () => {
    const scoreboards = world.scoreboard.getObjectives();
    let maxLives = 3; // Valor padrão (caso não exista o scoreboard "maxlives")

    // Percorre todos os scoreboards e busca por "maxlives:(numero)"
    scoreboards.forEach((objective) => {
        const name = objective.id;

        if (name.startsWith("maxlives.")) {
            const maxLivesValue = parseInt(name.split(".")[1]);
            if (!isNaN(maxLivesValue)) {
                maxLives = maxLivesValue; // Atualiza para o valor definido
            }
        }
    });

    return maxLives;
};

// Criar ou recuperar o scoreboard chamado 'Lives'
const objectiveName = "Lives";
let livesObjective = world.scoreboard.getObjective(objectiveName);
if (!livesObjective) {
    livesObjective = world.scoreboard.addObjective(objectiveName, "Vidas");
}

// Função para inicializar as vidas do jogador
const initializePlayerLives = (player) => {
    const identity = player.scoreboardIdentity;
    if (!identity) return; // Certifica que a identidade de scoreboard existe

    let playerScore = livesObjective.getScore(identity);
    const maxLives = getMaxLives(); // Busca o valor máximo de vidas

    // Se o jogador não tiver uma pontuação, define a vida máxima encontrada
    if (playerScore === undefined || playerScore === null) {
        livesObjective.setScore(identity, maxLives);
    }
};

// Função para atualizar o número de vidas na action bar
const updateActionBar = (player, lives) => {
    let color = "§a"; // Verde para 3 vidas
    if (lives === 2) color = "§e"; // Amarelo para 2 vidas
    else if (lives === 1) color = "§4"; // Vermelho para 1 vida

    player.onScreenDisplay.setActionBar(`${color}${lives}`);
};

// Evento quando o jogador entra
world.afterEvents.playerJoin.subscribe(({ playerId, playerName }) => {
    // Como o objeto 'player' não está disponível diretamente, recuperamos o jogador pelo nome
    const player = world.getPlayers().find(p => p.name === playerName);
    if (player) {
        initializePlayerLives(player); // Inicializa ou recupera as vidas
    }
});

// Função para verificar se o jogador está agachado e atualizar a action bar
const checkSneakingPlayers = () => {
    for (const player of world.getPlayers()) {
        const identity = player.scoreboardIdentity;
        if (!identity) continue; // Certifica que a identidade de scoreboard existe
        
        let playerScore = livesObjective.getScore(identity);

        // Se o jogador estiver agachado (isSneaking)
        if (player.isSneaking) {
            updateActionBar(player, playerScore); // Mostra as vidas restantes na action bar
        }
    }
};

// Executar a cada 40 ticks (2 segundos)
system.runInterval(() => {
	world.gameRules.keepInventory = true
    checkSneakingPlayers();
}, 40);

// Evento quando o jogador morre
world.afterEvents.entityDie.subscribe(({ deadEntity: player }) => {
    if (player.typeId !== 'minecraft:player') return;

    const identity = player.scoreboardIdentity;
    if (!identity) return; // Certifica que a identidade de scoreboard existe

    let playerScore = livesObjective.getScore(identity);
    const maxLives = getMaxLives(); // Recupera o valor máximo de vidas

    // Se o jogador já estiver com 0 ou menos vidas, resetar para o máximo
    if (playerScore <= 0) {
        livesObjective.setScore(identity, maxLives);
    } else if (playerScore === 1) {
        // Dropar itens do inventário na última vida
        const inv = player.getComponent('inventory').container;
        const location = player.location;

        for (let i = 0; i < inv.size; i++) {
            const item = inv.getItem(i);
            if (item) player.dimension.spawnItem(item, location);
        }

        // Dropar itens equipados
        const equippable = player.getComponent("minecraft:equippable");
        const equipmentSlots = [
            EquipmentSlot.Head, 
            EquipmentSlot.Chest, 
            EquipmentSlot.Legs, 
            EquipmentSlot.Feet, 
            EquipmentSlot.Offhand
        ];

        equipmentSlots.forEach((slot) => {
            const item = equippable.getEquipment(slot);
            if (item) {
                player.dimension.spawnItem(item, location);
                equippable.setEquipment(slot, undefined); // Remover o item equipado
            }
        });

        // Limpar inventário
        inv.clearAll();

        // Resetar vidas para o valor máximo ao morrer na última vida
        livesObjective.setScore(identity, maxLives);
    } else {
        // Diminuir as vidas se o jogador tiver mais que uma
        livesObjective.setScore(identity, playerScore - 1);
    }
});